@@ -1,3 +1,4 @@
+from os import access
 import shutil
 
 import torch
@@ -497,10 +498,10 @@ class trainer:
         return output
 
     def upload(self, hf_username, model_name):
-        hf_password = getpass("Enter your HuggingFace password")
+        hf_password = getpass("Enter your HuggingFace access token")
         if Path("./model").exists():
             shutil.rmtree("./model")
-        token = HfApi().login(username=hf_username, password=hf_password)
+        token = HfApi().set_access_token(access_token=hf_password)
         del hf_password
         model_url = HfApi().create_repo(token=token, name=model_name, exist_ok=True)
         model_repo = Repository(
